@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc,v 1.1.1.1 2003/01/21 13:41:28 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.cc 114 2004-02-10 14:50:18Z murrayc $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -25,7 +25,7 @@ ExampleWindow::ExampleWindow()
   set_title("togglebutton example");
   set_border_width(10);
 
-  m_button.signal_clicked().connect( SigC::slot(*this, &ExampleWindow::on_button_clicked) );
+  m_button.signal_clicked().connect( sigc::mem_fun(*this, &ExampleWindow::on_button_clicked) );
   
   add(m_button);
 
