@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc,v 1.2 2003/10/18 15:34:44 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.cc 114 2004-02-10 14:50:18Z murrayc $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -26,7 +26,7 @@ ExampleWindow::ExampleWindow()
   set_title("Gtk::FontSelectionDialog example");
   
   add(m_Button);  
-  m_Button.signal_font_set().connect( SigC::slot(*this, &ExampleWindow::on_button_font_set) );
+  m_Button.signal_font_set().connect( sigc::mem_fun(*this, &ExampleWindow::on_button_font_set) );
   
   show_all_children();
 }
