@@ -1,4 +1,4 @@
-//$Id: dndwindow.h,v 1.3 2004/01/29 20:47:34 murrayc Exp $ -*- c++ -*-
+//$Id: dndwindow.h 114 2004-02-10 14:50:18Z murrayc $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -76,8 +76,8 @@ protected:
   Gtk::Window m_PopupWindow;  //This is a candidate for being a separate class.
   bool m_popped_up;
   bool m_in_popup;
-  SigC::Connection m_popdown_timer;
-  SigC::Connection m_popup_timer;
+  sigc::connection m_popdown_timer;
+  sigc::connection m_popup_timer;
 
   //Positions in the targets list:
   enum
